aboutsummaryrefslogtreecommitdiffstats
path: root/config
diff options
context:
space:
mode:
Diffstat (limited to 'config')
-rw-r--r--config/config.sample.php92
1 files changed, 68 insertions, 24 deletions
diff --git a/config/config.sample.php b/config/config.sample.php
index 32354966949..e09b0904808 100644
--- a/config/config.sample.php
+++ b/config/config.sample.php
@@ -152,6 +152,14 @@ $CONFIG = [
'dbpersistent' => '',
/**
+ * Specify read only replicas to be used by Nextcloud when querying the database
+ */
+'dbreplica' => [
+ ['user' => 'nextcloud', 'password' => 'password1', 'host' => 'replica1', 'dbname' => ''],
+ ['user' => 'nextcloud', 'password' => 'password2', 'host' => 'replica2', 'dbname' => ''],
+],
+
+/**
* Indicates whether the Nextcloud instance was installed successfully; ``true``
* indicates a successful installation, and ``false`` indicates an unsuccessful
* installation.
@@ -229,12 +237,28 @@ $CONFIG = [
'force_locale' => 'en_US',
/**
+ * This sets the default timezone on your Nextcloud server, using IANA
+ * identifiers like ``Europe/Berlin`` or ``Pacific/Auckland``. The default
+ * timezone parameter is only used when the timezone of the user can't be
+ * determined.
+ *
+ * Defaults to ``UTC``
+ */
+'default_timezone' => 'Europe/Berlin',
+
+/**
* ``true`` enables the Help menu item in the user menu (top right of the
* Nextcloud Web interface). ``false`` removes the Help item.
*/
'knowledgebaseenabled' => true,
/**
+ * ``true`` embeds the documentation in an iframe inside Nextcloud.
+ * ``false`` only shows buttons to the online documentation.
+ */
+'knowledgebase.embedded' => false,
+
+/**
* ``true`` allows users to change their display names (on their Personal
* pages), and ``false`` prevents them from changing their display names.
*/
@@ -344,7 +368,7 @@ $CONFIG = [
'token_auth_activity_update' => 60,
/**
- * Whether the bruteforce protection shipped with Nextcloud should be enabled or not.
+ * Whether the brute force protection shipped with Nextcloud should be enabled or not.
*
* Disabling this is discouraged for security reasons.
*
@@ -353,9 +377,9 @@ $CONFIG = [
'auth.bruteforce.protection.enabled' => true,
/**
- * Whether the bruteforce protection shipped with Nextcloud should be set to testing mode.
+ * Whether the brute force protection shipped with Nextcloud should be set to testing mode.
*
- * In testing mode bruteforce attempts are still recorded, but the requests do
+ * In testing mode brute force attempts are still recorded, but the requests do
* not sleep/wait for the specified time. They will still abort with
* "429 Too Many Requests" when the maximum delay is reached.
* Enabling this is discouraged for security reasons
@@ -971,6 +995,15 @@ $CONFIG = [
'loglevel_frontend' => 2,
/**
+ * Loglevel used by the dirty database query detection. Useful to identify
+ * potential database bugs in production. Set this to loglevel or higher to
+ * see dirty queries in the logs.
+ *
+ * Defaults to ``0`` (debug)
+ */
+'loglevel_dirty_database_queries' => 0,
+
+/**
* If you maintain different instances and aggregate the logs, you may want
* to distinguish between them. ``syslog_tag`` can be set per instance
* with a unique id. Only available if ``log_type`` is set to ``syslog`` or
@@ -1231,14 +1264,6 @@ $CONFIG = [
* Defaults to ``''`` (empty string)
*/
'preview_libreoffice_path' => '/usr/bin/libreoffice',
-/**
- * Use this if LibreOffice/OpenOffice requires additional arguments.
- *
- * Defaults to ``''`` (empty string)
- */
-'preview_office_cl_parameters' =>
- ' --headless --nologo --nofirststartwizard --invisible --norestore '.
- '--convert-to png --outdir ',
/**
* custom path for ffmpeg binary
@@ -1279,6 +1304,7 @@ $CONFIG = [
* - ``OC\Preview\StarOffice``
* - ``OC\Preview\SVG``
* - ``OC\Preview\TIFF``
+ * - ``OC\Preview\EMF``
*
*
* Defaults to the following providers:
@@ -1920,7 +1946,9 @@ $CONFIG = [
* where the default `datadirectory` is on network disk like NFS, or is otherwise
* restricted. Defaults to the value of `datadirectory` if unset.
*
- * The Web server user must have write access to this directory.
+ * If set, the value MUST be located _outside_ of the installation directory of Nextcloud and
+ * writable by the Web server user.
+ *
*/
'updatedirectory' => '',
@@ -1934,6 +1962,19 @@ $CONFIG = [
'blacklisted_files' => ['.htaccess'],
/**
+ * Blacklist characters from being used in filenames. This is useful if you
+ * have a filesystem or OS which does not support certain characters like windows.
+ *
+ * The '/' and '\' characters are always forbidden.
+ *
+ * Example for windows systems: ``array('?', '<', '>', ':', '*', '|', '"', chr(0), "\n", "\r")``
+ * see https://en.wikipedia.org/wiki/Comparison_of_file_systems#Limits
+ *
+ * Defaults to ``array()``
+ */
+'forbidden_chars' => [],
+
+/**
* If you are applying a theme to Nextcloud, enter the name of the theme here.
* The default location for themes is ``nextcloud/themes/``.
*
@@ -1944,7 +1985,7 @@ $CONFIG = [
/**
* Enforce the user theme. This will disable the user theming settings
* This must be a valid ITheme ID.
* E.g. light, dark, highcontrast, dark-highcontrast...
*/
'enforce_theme' => '',
@@ -2329,17 +2370,6 @@ $CONFIG = [
'profile.enabled' => true,
/**
- * Enable file metadata collection
- *
- * This is helpful for the mobile clients and will enable few optimizations in
- * the future for the preview generation.
- *
- * Note that when enabled, this data will be stored in the database and might increase
- * the database storage.
- */
-'enable_file_metadata' => true,
-
-/**
* Allows to override the default scopes for Account data.
* The list of overridable properties and valid values for scopes are in
* ``OCP\Accounts\IAccountManager``. Values added here are merged with
@@ -2378,4 +2408,18 @@ $CONFIG = [
* Defaults to ``true``
*/
'reference_opengraph' => true,
+
+/**
+ * Enable use of old unified search
+ *
+ * Defaults to ``false``
+ */
+'unified_search.enabled' => false,
+
+/**
+ * Enable features that are do respect accessibility standards yet.
+ *
+ * Defaults to ``true``
+ */
+'enable_non-accessible_features' => true,
];
@@ -1944,7 +1985,7 @@ $CONFIG = [
* Enforce the user theme. This will disable the user theming settings
* This must be a valid ITheme ID.
- * E.g. light, dark, highcontrast, dark-highcontrast...
+ * E.g. dark, dark-highcontrast, default, light, light-highcontrast, opendyslexic
*/
'enforce_theme' => '',